@@ -1,5 +1,5 @@
 #Boa:Dialog:About
-#TunaPie (c)2005-2006 James Stone.
+#TunaPie (c)2005-2008 James Stone.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -18,13 +18,10 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 0.2.31 19/11/06
+#Version 0.2.48  24/01/08
 
-import wxversion
-wxversion.select("2.6")
 import wx
 from wx.lib.anchors import LayoutAnchors
-from wxPython.lib.anchors import LayoutAnchors
 import wx.lib.stattext
 
 def create(parent):
@@ -38,7 +35,7 @@ class About(wx.Dialog):
     def _init_ctrls(self, prnt):
         # generated method, don't edit
         wx.Dialog.__init__(self, id=wxID_ABOUT, name='About', parent=prnt,
-              pos=wx.Point(268, 259), size=wx.Size(438, 124),
+              pos=wx.Point(288, 285), size=wx.Size(438, 124),
               style=wx.DEFAULT_DIALOG_STYLE, title='About TunaPie')
         self.SetClientSize(wx.Size(438, 124))
         self.Show(True)
@@ -60,8 +57,8 @@ class About(wx.Dialog):
         self.genStaticText1.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
 
         self.genStaticText2 = wx.lib.stattext.GenStaticText(ID=wxID_ABOUTGENSTATICTEXT2,
-              label=u'Version 1.3.1 (c) 2005-2006 James Stone jamesmstone@gmail.com',
-              name='genStaticText2', parent=self, pos=wx.Point(10, 40),
+              label=u'Version 2.1.5 (c) 2005-2008 James Stone jamesmstone@gmail.com',
+              name='genStaticText2', parent=self, pos=wx.Point(2, 48),
               size=wx.Size(327, 12), style=0)
         self.genStaticText2.SetFont(wx.Font(7, 77, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
@@ -74,7 +71,7 @@ class About(wx.Dialog):
 
         self.genStaticText3 = wx.lib.stattext.GenStaticText(ID=wxID_ABOUTGENSTATICTEXT3,
               label='Released under the GNU GPL', name='genStaticText3',
-              parent=self, pos=wx.Point(8, 72), size=wx.Size(162, 13), style=0)
+              parent=self, pos=wx.Point(8, 80), size=wx.Size(162, 13), style=0)
         self.genStaticText3.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText3.SetFont(wx.Font(8, 77, wx.NORMAL, wx.NORMAL, False,
               u'Sans'))
