@@ -1,5 +1,5 @@
 #Boa:Dialog:recqueue
-#TunaPie (c)2005-2006 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 0.0.4 26/09/06
+#Version 0.0.5 27/04/07
 
 import wx
 import os
@@ -48,17 +48,21 @@ class recqueue(wx.Dialog):
         self.deleteButton = wx.Button(id=wxID_RECQUEUEDELETEBUTTON,
               label=u'Delete', name=u'deleteButton', parent=self,
               pos=wx.Point(48, 408), size=wx.Size(85, 24), style=0)
-        self.deleteButton.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL,
+        self.deleteButton.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
+        self.deleteButton.SetAutoLayout(True)
+        self.deleteButton.SetThemeEnabled(True)
         self.deleteButton.Bind(wx.EVT_BUTTON, self.OnDeleteButtonButton,
               id=wxID_RECQUEUEDELETEBUTTON)
 
         self.OKbutton = wx.Button(id=wxID_RECQUEUEOKBUTTON, label=u'OK',
               name=u'OKbutton', parent=self, pos=wx.Point(250, 408),
               size=wx.Size(85, 24), style=0)
-        self.OKbutton.SetFont(wx.Font(7, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
+        self.OKbutton.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
               u'Helvetica'))
         self.OKbutton.SetThemeEnabled(True)
+        self.OKbutton.SetAutoLayout(True)
+        self.OKbutton.SetDefault()
         self.OKbutton.Bind(wx.EVT_BUTTON, self.OnOKbuttonButton,
               id=wxID_RECQUEUEOKBUTTON)
 
