@@ -1,9 +1,10 @@
 #Boa:Dialog:RecordStream
-#TunaPie (c)2005-2006 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
 #Written using Boa-Constructor.
-#Version 0.0.4 26/07/06
+#Version 0.0.7 05/09/07
 
 import wx
+import wx.lib.masked.textctrl
 import wx.lib.intctrl
 import wx.lib.masked.timectrl
 import wx.lib.stattext
@@ -30,7 +31,7 @@ class RecordStream(wx.Dialog):
     def _init_ctrls(self, prnt):
         # generated method, don't edit
         wx.Dialog.__init__(self, id=wxID_RECORDSTREAM, name=u'RecordStream',
-              parent=prnt, pos=wx.Point(354, 256), size=wx.Size(280, 216),
+              parent=prnt, pos=wx.Point(516, 218), size=wx.Size(280, 216),
               style=wx.DEFAULT_DIALOG_STYLE, title=u'Record Stream')
         self.SetClientSize(wx.Size(280, 216))
         self.SetBackgroundColour(wx.Colour(212, 216, 224))
@@ -39,10 +40,10 @@ class RecordStream(wx.Dialog):
 
         self.genStaticText1 = wx.lib.stattext.GenStaticText(ID=wxID_RECORDSTREAMGENSTATICTEXT1,
               label=u'Start Recording', name='genStaticText1', parent=self,
-              pos=wx.Point(8, 8), size=wx.Size(75, 15), style=0)
+              pos=wx.Point(8, 8), size=wx.Size(75, 17), style=0)
         self.genStaticText1.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
-        self.genStaticText1.SetBackgroundColour(wx.Colour(212, 216, 224))
+        self.genStaticText1.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText1.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText1.SetThemeEnabled(True)
 
@@ -72,19 +73,19 @@ class RecordStream(wx.Dialog):
 
         self.genStaticText2 = wx.lib.stattext.GenStaticText(ID=wxID_RECORDSTREAMGENSTATICTEXT2,
               label=u'(H:M 24H)', name='genStaticText2', parent=self,
-              pos=wx.Point(176, 72), size=wx.Size(51, 15), style=0)
+              pos=wx.Point(176, 72), size=wx.Size(51, 17), style=0)
         self.genStaticText2.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
-        self.genStaticText2.SetBackgroundColour(wx.Colour(212, 216, 224))
+        self.genStaticText2.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText2.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText2.SetThemeEnabled(True)
 
         self.genStaticText3 = wx.lib.stattext.GenStaticText(ID=wxID_RECORDSTREAMGENSTATICTEXT3,
               label=u'On:', name='genStaticText3', parent=self, pos=wx.Point(24,
-              104), size=wx.Size(17, 15), style=0)
+              104), size=wx.Size(17, 17), style=0)
         self.genStaticText3.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
-        self.genStaticText3.SetBackgroundColour(wx.Colour(212, 216, 224))
+        self.genStaticText3.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText3.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText3.SetThemeEnabled(True)
 
@@ -113,6 +114,7 @@ class RecordStream(wx.Dialog):
         self.OKbutton.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
               u'Helvetica'))
         self.OKbutton.SetThemeEnabled(True)
+        self.OKbutton.SetDefault()
         self.OKbutton.Bind(wx.EVT_BUTTON, self.OnOKbuttonButton,
               id=wxID_RECORDSTREAMOKBUTTON)
 
@@ -129,10 +131,10 @@ class RecordStream(wx.Dialog):
 
         self.genStaticText4 = wx.lib.stattext.GenStaticText(ID=wxID_RECORDSTREAMGENSTATICTEXT4,
               label=u'Stopping in', name='genStaticText4', parent=self,
-              pos=wx.Point(24, 144), size=wx.Size(53, 15), style=0)
+              pos=wx.Point(24, 144), size=wx.Size(53, 17), style=0)
         self.genStaticText4.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
-        self.genStaticText4.SetBackgroundColour(wx.Colour(212, 216, 224))
+        self.genStaticText4.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText4.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText4.SetThemeEnabled(True)
 
@@ -152,19 +154,19 @@ class RecordStream(wx.Dialog):
 
         self.genStaticText5 = wx.lib.stattext.GenStaticText(ID=wxID_RECORDSTREAMGENSTATICTEXT5,
               label=u'hours', name='genStaticText5', parent=self,
-              pos=wx.Point(136, 152), size=wx.Size(27, 15), style=0)
+              pos=wx.Point(136, 152), size=wx.Size(27, 17), style=0)
         self.genStaticText5.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
-        self.genStaticText5.SetBackgroundColour(wx.Colour(212, 216, 224))
+        self.genStaticText5.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText5.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText5.SetThemeEnabled(True)
 
         self.genStaticText6 = wx.lib.stattext.GenStaticText(ID=wxID_RECORDSTREAMGENSTATICTEXT6,
               label=u'minutes', name='genStaticText6', parent=self,
-              pos=wx.Point(208, 152), size=wx.Size(37, 15), style=0)
+              pos=wx.Point(208, 152), size=wx.Size(37, 17), style=0)
         self.genStaticText6.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL,
               False, u'Helvetica'))
-        self.genStaticText6.SetBackgroundColour(wx.Colour(212, 216, 224))
+        self.genStaticText6.SetBackgroundColour(wx.Colour(220, 218, 213))
         self.genStaticText6.SetBackgroundStyle(wx.BG_STYLE_SYSTEM)
         self.genStaticText6.SetThemeEnabled(True)
 
@@ -213,23 +215,17 @@ class RecordStream(wx.Dialog):
         self.Close()
 
     def OnOKbuttonButton(self, event):
-        if (self.nowradio.GetValue()==True):
-            tuner.recordselection(self.recordoptions[0],self.recordoptions[1]\
-                ,self.recordoptions[2],self.recordoptions[3],self.recordoptions[4])
-            self.Close()
-            return
-        #print self.time.GetValue()
-        atcommand=popen2.Popen4('at '+self.time.GetValue()+' '+self.monthchoice.GetStringSelection()\
-            +' '+self.datechoice.GetStringSelection())
-        #this bit all from tuner module. Maybe can make this cleaner sometime.
-        ripper=self.recordoptions[2]
-        pls=self.recordoptions[3]
-        rdir=self.recordoptions[4]
+        ripper=self.recordoptions[1]
+        pls=self.recordoptions[2]
+        rdir=self.recordoptions[3]
         playlist=urllib.urlopen(pls)
         tempfile=playlist.read()
         url=tempfile[tempfile.find('//')+2:tempfile.find('\n',50)]
         r=ripper.split(' ')
-        args=r[0]
+        if (self.nowradio.GetValue()==True):
+            args=' -e \"'+r[0]
+        else:
+            args=r[0]
         args+=' http://'+url
         i=0
         directoryset=0
@@ -242,9 +238,17 @@ class RecordStream(wx.Dialog):
         if not(directoryset):
             args+=' -d'
             args+=' '+rdir
-        args +=' -l '+str((self.stophours.GetValue()*3600)+(self.stopmins.GetValue()*60))
+        if (self.nowradio.GetValue()==True):
+            args+='\"'
+            tuner.recordselection(self.recordoptions[0], args)
+            print self.recordoptions[0], args
+            self.Close()
+            return
+        args +=' -l '+str((self.stophours.GetValue()*3600)+(self.stopmins.GetValue()*60))     
         print ('at '+self.time.GetValue()+' '+self.monthchoice.GetStringSelection()\
             +' '+self.datechoice.GetStringSelection()+'\n'+'call: '+args)
+        atcommand=popen2.Popen4('at '+self.time.GetValue()+' '+self.monthchoice.GetStringSelection()\
+            +' '+self.datechoice.GetStringSelection())
         atcommand.tochild.write(args)
         atcommand.tochild.close()
         self.Close()
