@@ -1,4 +1,4 @@
-#TunaPie (c)2005-2006 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -14,10 +14,9 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
-#Version 0.3.14 19/11/06
+#Version 0.4.1 25/01/08
 
 import urllib
-import popen2
 import getpass
 import fcntl
 import os
@@ -26,11 +25,15 @@ import string
 import re
 import commands
 import unicodedata
+import time
 
 def pkill(program):
+    flag=""
     rip = program
     me = commands.getoutput("whoami")
-    p = commands.getoutput("ps -u %s -o comm -o pid" % me)
+    if sys.platform.find("linux")==-1:
+        flag="-"
+    p = commands.getoutput("ps "+flag+"U "+me+" "+flag+"o pid "+flag+"o command")
     ids = p.split("\n")
     found=0
     firstrun=1
@@ -43,10 +46,13 @@ def pkill(program):
             else:
                 found=1
             firstrun=0
-        regex = re.compile(r'(\d+).*',re.I)
-        id = regex.sub(r'\1', id)
+        id=id.split(" ")
+        try: 
+            id=str(int(id[0]))
+        except:
+            id=str(int(id[1]))
         commands.getoutput("kill -15 %s" % id)
-        if commands.getoutput("ps -u %s -o fname -o pid" % me).find(id) > -1:
+        if commands.getoutput("ps "+flag+"U "+me+" "+flag+"o pid "+flag+"o command").find(id) > -1:
             commands.getoutput("kill -9 %s" % id)
     return found
 
@@ -165,14 +171,6 @@ def decodeice(file,radio):
         nameend=data.find('</b>',name)
         title=data.find('title="',nameend)
         titleend=data.find('"',title+7)
-        if not(radio):
-            if data[title+7:titleend]!='NSV Video':
-                pos=titleend+1
-                continue
-        else:
-            if data[title+7:titleend]=='NSV Video':
-                pos=titleend+1
-                continue
         preurl=data.find('Now playing on',titleend)
         url=data.find('href="',preurl)
         urlend=data.find('"',url+6)
@@ -182,6 +180,14 @@ def decodeice(file,radio):
         pregenre=data.find('font',playingend+7)
         genre=data.find('>',pregenre)
         genreend=data.find('</font>',genre)
+        if not(radio):
+            if (data[genre:genreend].lower().find('video')==-1 and data[genre:genreend].lower().find('tv')==-1):
+                pos=titleend+1
+                continue
+        else:
+            if data[genre:genreend].lower().find('video')>-1|data[genre:genreend].lower().find('tv')>-1:
+                pos=titleend+1
+                continue
         bitrate=data.find('center>',genreend)
         bitrateend=data.find('<',bitrate)
         listeners="0"
@@ -206,40 +212,22 @@ def decodeice(file,radio):
         stationbitrate.append(bitrate)
 
 def playselection(mediaplayer,pls,info=0):
-    tempfile=open('/tmp/'+getpass.getuser()+'_tunapie_temp.pls','w')
+    commands.getoutput("rm -rf /tmp/"+getpass.getuser()+"*_tunapie_temp.pls")
+    tstamp=str(time.time())
+    tempfile=open('/tmp/'+getpass.getuser()+tstamp+'_tunapie_temp.pls','w')
     playlist=urllib.urlopen(pls)
     if (info):
         return playlist.readlines()
     plist=playlist.readlines()
     for line in plist:
         tempfile.write(line)
-    if len(plist)==1:
-        player=popen2.Popen4(mediaplayer+' '+plist[0])
-    else:
-        player=popen2.Popen4(mediaplayer+' /tmp/'+getpass.getuser()+'_tunapie_temp.pls')
-    return player.pid
+    os.spawnv(os.P_NOWAIT,commands.getoutput("which "+mediaplayer),[mediaplayer,'/tmp/'+getpass.getuser()+tstamp+'_tunapie_temp.pls'])
 
 def playvid(mediaplayer,pls):
-    playlist=urllib.urlopen(pls)
-    tfile=playlist.read()
-    urlstart=0
-    urlend=0
-    urlstring=''
-    while 1:
-        urlstart=tfile.find('//',urlend)
-        if urlstart==-1:
-            break
-        urlend=tfile.find('\n',urlstart)
-        url=tfile[urlstart+2:urlend]
-        if url.find('/')>-1:
-            url=url[0:url.find('/')]
-        if url.find(':')>-1: #this is a hack to ignore other urls (non-stream) in the playlist
-            urlstring+=' http://'+url
-    player=popen2.Popen4(mediaplayer+urlstring)
-    output=player.fromchild
-    outputfd=output.fileno()
-    unblock(outputfd)
-    return (player.pid, output, outputfd)
+    playercommands=mediaplayer.split(" ")
+    vidplayer=commands.getoutput("which "+str(playercommands[0]))
+    playercommands.append(pls)
+    os.spawnv(os.P_NOWAIT, vidplayer, playercommands)
 
 def savefavorites(home,favname,favurl,favlist,favplay,favbit,favgen,favmod):
     favfile=open(home+'/.tunapie/favorites','w')
@@ -252,7 +240,7 @@ def savefavorites(home,favname,favurl,favlist,favplay,favbit,favgen,favmod):
         favfile.write('lc="'+favlist[i]+'"\n')
         favfile.write('mod="'+str(favmod[i])+'"\n')
 
-def writeprefs(home,audio,video,term,rip,rdir,shoutice,maxd,fontsize):
+def writeprefs(home,audio,video,term,rip,rdir,shoutice,maxd,fontsize,browser):
     preffile=open(home+'/.tunapie/prefs','w')
     preffile.write("audioplayer="+audio+'\n')
     preffile.write("videoplayer="+video+'\n')
@@ -262,43 +250,30 @@ def writeprefs(home,audio,video,term,rip,rdir,shoutice,maxd,fontsize):
     preffile.write("icecast(0)/shoutcast(1)="+str(int(shoutice))+'\n')
     preffile.write("max streams to display="+str(int(maxd))+'\n')
     preffile.write("font size="+str(int(fontsize))+'\n')
+    preffile.write("web browser="+browser+'\n')
 
-def readprefs(home,media,video,term,rip,rdir,shoutice,maxd,fontsize):
+def readprefs(home,rdir,shoutice,maxd,fontsize):
     try: preffile=open(home+'/.tunapie/prefs','r')
     except IOError:
-        return media,video,term,rip,rdir,shoutice,maxd,fontsize
+        return "","","","",rdir,shoutice,maxd,fontsize,""
     preferences=preffile.read().split('\n')
     returnvals=[]
     for i in preferences:
         try:returnvals.append(i.split("=")[1])
         except IndexError: pass
-    if len(returnvals)<8:
-        return media,video,term,rip,rdir,shoutice,maxd,fontsize
+    if len(returnvals)<9:
+        return "","","","",rdir,shoutice,maxd,fontsize,""
     return(returnvals[0],returnvals[1],returnvals[2],returnvals[3],\
-            returnvals[4],returnvals[5],returnvals[6], returnvals[7])
+            returnvals[4],returnvals[5],returnvals[6], returnvals[7],\
+            returnvals[8])
                 
-def recordselection(terminal,command,ripper,pls,rdir):
-    playlist=urllib.urlopen(pls)
-    tempfile=playlist.read()
-    url=tempfile[tempfile.find('//')+2:tempfile.find('\n',50)]
-    r=ripper.split(' ')
-    args=[terminal,command]
-    args.append(r[0])
-    args.append('http://'+url)
-    i=0
-    directoryset=0
-    for argument in r:
-        i+=1
-        if i==1: continue
-        args.append(argument)
-        if argument=='-d':
-            directoryset=1
-    if not(directoryset):
-        args.append('-d')
-        args.append(rdir)
-    #print args
-    process=os.spawnv(os.P_NOWAIT,terminal,args)
-    return process
+def recordselection(terminal,args):
+    recordcommand=[terminal,url]
+    os.spawnv(os.P_NOWAIT,commands.getoutput("which "+terminal),recordcommand)
+
+def showpage(browser,url):
+    urlcommand=[browser,url]
+    os.spawnv(os.P_NOWAIT,commands.getoutput("which "+browser),urlcommand)
 
 def adultset():
     try: adultconfig=open('/etc/tunapie.config')
